@@ -27,21 +27,18 @@
 #include "alarmdockwindow.h"
 
 #include <QAction>
-#include <KActionCollection>
 #include <KConfigGroup>
 #include <KIconEffect>
 #include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KStandardAction>
 #include <KToolInvocation>
 #include <KSharedConfig>
-
 #include <QMenu>
 #include "koalarmclient_debug.h"
 
 AlarmDockWindow::AlarmDockWindow()
-    : KStatusNotifierItem(0)
+    : KStatusNotifierItem(nullptr)
 {
     // Read the autostart status from the config file
     KConfigGroup config(KSharedConfig::openConfig(), "General");
