@@ -58,22 +58,24 @@
 #include <KCheckableProxyModel>
 #include <KConfigGroup>
 #include <KMessageBox>
+
+#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
 #include <KRecursiveFilterProxyModel>
+#else
+#include <QSortFilterProxyModel>
+#endif
 #include "korganizer_debug.h"
 
 #include <QAction>
 #include <QColorDialog>
-#include <QDialog>
 #include <QHeaderView>
 #include <QLineEdit>
-#include <QPainter>
 #include <QStackedWidget>
-#include <QStyledItemDelegate>
 #include <QVBoxLayout>
 
 static Akonadi::EntityTreeModel *findEtm(QAbstractItemModel *model)
 {
-    QAbstractProxyModel *proxyModel;
+    QAbstractProxyModel *proxyModel = nullptr;
     while (model) {
         proxyModel = qobject_cast<QAbstractProxyModel *>(model);
         if (proxyModel && proxyModel->sourceModel()) {
@@ -123,7 +125,7 @@ private Q_SLOTS:
     }
 
 private:
-    QAbstractItemModel *mCheckableProxy;
+    QAbstractItemModel *mCheckableProxy = nullptr;
 };
 
 /**
@@ -231,8 +233,8 @@ private:
     }
 
     QPointer<Akonadi::ETMViewStateSaver> treeStateRestorer;
-    QTreeView *mTreeView;
-    bool mExpandAll;
+    QTreeView *mTreeView = nullptr;
+    bool mExpandAll = false;
     QString mTreeStateConfig;
 };
 
@@ -565,12 +567,22 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
     searchProxy->setSourceModel(collectionFilter);
     searchProxy->setObjectName(QStringLiteral("searchProxy"));
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
     KRecursiveFilterProxyModel *filterTreeViewModel = new KRecursiveFilterProxyModel(this);
     filterTreeViewModel->setDynamicSortFilter(true);
     filterTreeViewModel->setSourceModel(searchProxy);
     filterTreeViewModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
 //   filterTreeViewModel->setObjectName( "Recursive filtering, for the search bar" );
     connect(searchCol, &QLineEdit::textChanged, filterTreeViewModel, &KRecursiveFilterProxyModel::setFilterWildcard);
+#else
+    QSortFilterProxyModel *filterTreeViewModel = new QSortFilterProxyModel(this);
+    filterTreeViewModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
+    filterTreeViewModel->setRecursiveFiltering(true);
+    filterTreeViewModel->setDynamicSortFilter(true);
+    filterTreeViewModel->setSourceModel(searchProxy);
+//   filterTreeViewModel->setObjectName( "Recursive filtering, for the search bar" );
+    connect(searchCol, &QLineEdit::textChanged, filterTreeViewModel, &QSortFilterProxyModel::setFilterWildcard);
+#endif
 
     SortProxyModel *searchSortProxy = new SortProxyModel(this);
     searchSortProxy->setSourceModel(filterTreeViewModel);
@@ -753,13 +765,11 @@ void AkonadiCollectionView::assignColor()
     const Akonadi::Collection collection = CalendarSupport::collectionFromIndex(index);
     Q_ASSERT(collection.isValid());
 
-    const QString identifier = QString::number(collection.id());
-    const QColor defaultColor = KOPrefs::instance()->resourceColor(identifier);
+    const QColor defaultColor = KOHelper::resourceColor(collection);
     QColor myColor;
     myColor = QColorDialog::getColor(defaultColor);
     if (myColor.isValid() && myColor != defaultColor) {
-        KOPrefs::instance()->setResourceColor(identifier, myColor);
-        KOPrefs::instance()->eventViewsPreferences()->writeConfig();
+        KOHelper::setResourceColor(collection, myColor);
         Q_EMIT colorsChanged();
         updateMenu();
         updateView();
@@ -772,9 +782,7 @@ void AkonadiCollectionView::disableColor()
     Q_ASSERT(index.isValid());
     const Akonadi::Collection collection = CalendarSupport::collectionFromIndex(index);
     Q_ASSERT(collection.isValid());
-    const QString identifier = QString::number(collection.id());
-    KOPrefs::instance()->setResourceColor(identifier, QColor());
-    KOPrefs::instance()->eventViewsPreferences()->writeConfig();
+    KOHelper::setResourceColor(collection, QColor());
     updateMenu();
     updateView();
     Q_EMIT colorsChanged();
@@ -830,8 +838,7 @@ void AkonadiCollectionView::updateMenu()
         const Akonadi::Collection collection = CalendarSupport::collectionFromIndex(index);
 
         if (collection.isValid() && !collection.contentMimeTypes().isEmpty()) {
-            const QString identifier = QString::number(collection.id());
-            const QColor defaultColor = KOPrefs::instance()->resourceColor(identifier);
+            const QColor defaultColor = KOHelper::resourceColor(collection);
             enableAction = enableAction && defaultColor.isValid();
             if (collection.remoteId() == QLatin1String("akonadi_birthdays_resource")) {
                 enableAction = false;
@@ -857,13 +864,13 @@ void AkonadiCollectionView::updateMenu()
 
 void AkonadiCollectionView::newCalendar()
 {
-    Akonadi::AgentTypeDialog dlg(this);
-    dlg.setWindowTitle(i18n("Add Calendar"));
-    dlg.agentFilterProxyModel()->addMimeTypeFilter(QStringLiteral("text/calendar"));
-    dlg.agentFilterProxyModel()->addCapabilityFilter(QStringLiteral("Resource"));   // show only resources, no agents
-    if (dlg.exec()) {
+    QPointer<Akonadi::AgentTypeDialog> dlg = new Akonadi::AgentTypeDialog(this);
+    dlg->setWindowTitle(i18n("Add Calendar"));
+    dlg->agentFilterProxyModel()->addMimeTypeFilter(QStringLiteral("text/calendar"));
+    dlg->agentFilterProxyModel()->addCapabilityFilter(QStringLiteral("Resource"));   // show only resources, no agents
+    if (dlg->exec()) {
         mNotSendAddRemoveSignal = true;
-        const Akonadi::AgentType agentType = dlg.agentType();
+        const Akonadi::AgentType agentType = dlg->agentType();
         if (agentType.isValid()) {
             Akonadi::AgentInstanceCreateJob *job = new Akonadi::AgentInstanceCreateJob(agentType, this);
             job->configure(this);
@@ -871,6 +878,7 @@ void AkonadiCollectionView::newCalendar()
             job->start();
         }
     }
+    delete dlg;
 }
 
 void AkonadiCollectionView::newCalendarDone(KJob *job)
